# libpythonprodihl
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.org/MarcosDihl/libpythonprodihl.svg?branch=main)](https://travis-ci.org/MarcosDihl/libpythonprodihl)
[![Updates](https://pyup.io/repos/github/MarcosDihl/libpythonprodihl/shield.svg)](https://pyup.io/repos/github/MarcosDihl/libpythonprodihl/)
[![Python 3](https://pyup.io/repos/github/MarcosDihl/libpythonprodihl/python-3-shield.svg)](https://pyup.io/repos/github/MarcosDihl/libpythonprodihl/)

Suportada versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/Scripts/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código:

```console
flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
